summaryrefslogtreecommitdiffstats
path: root/test/tfile.c
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2014-07-21 16:03:44 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2014-07-21 16:03:44 (GMT)
commit362bbe2440bc562f703f4587c578f83f1747eba5 (patch)
treeef5332f2e665f6c19a18a9d31f14b961f7d50732 /test/tfile.c
parent40d0fc76aead84d6cd719c6ab87d6f1635614f19 (diff)
downloadhdf5-362bbe2440bc562f703f4587c578f83f1747eba5.zip
hdf5-362bbe2440bc562f703f4587c578f83f1747eba5.tar.gz
hdf5-362bbe2440bc562f703f4587c578f83f1747eba5.tar.bz2
[svn-r25448] Description:
Initial tweaks to bring into alignment with trunk, during review process. Tested on: Mac OSX/64 10.9.3 (amazon) w/gcc 4.2.1 (h5committest not required on this branch)
Diffstat (limited to 'test/tfile.c')
-rw-r--r--test/tfile.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/test/tfile.c b/test/tfile.c
index 0bb20dd..dfdbf25 100644
--- a/test/tfile.c
+++ b/test/tfile.c
@@ -1576,13 +1576,13 @@ test_file_freespace(void)
/****************************************************************
**
** test_file_ishdf5(): low-level file test routine.
** This test checks whether the H5Fis_hdf5() routine is working
** correctly in variuous situations.
**
*****************************************************************/
static void
-test_file_ishdf5(void)
+test_file_isaccessible(void)
{
hid_t file; /* File opened with read-write permission */
hid_t fcpl; /* File creation property list */
@@ -1606,7 +1606,7 @@ test_file_ishdf5(void)
/* Verify that the file is an HDF5 file */
status = H5Fis_accessible(FILE1, H5P_DEFAULT);
- VERIFY(status, TRUE, "H5Fis_hdf5");
+ VERIFY(status, TRUE, "H5Fis_accessible");
/* Create a file creation property list with a non-default user block size */
@@ -1630,7 +1630,7 @@ test_file_ishdf5(void)
/* Verify that the file is an HDF5 file */
status = H5Fis_accessible(FILE1, H5P_DEFAULT);
- VERIFY(status, TRUE, "H5Fis_hdf5");
+ VERIFY(status, TRUE, "H5Fis_accessible");
/* Create non-HDF5 file and check it */
@@ -1651,9 +1651,9 @@ test_file_ishdf5(void)
/* Verify that the file is not an HDF5 file */
status = H5Fis_accessible(FILE1, H5P_DEFAULT);
- VERIFY(status, FALSE, "H5Fis_hdf5");
+ VERIFY(status, FALSE, "H5Fis_accessible");
-} /* end test_file_ishdf5() */
+} /* end test_file_isaccessible() */
/****************************************************************
**
@@ -3657,7 +3657,7 @@ test_file(void)
test_file_perm(); /* Test file access permissions */
test_file_perm2(); /* Test file access permission again */
test_file_freespace(); /* Test file free space information */
- test_file_ishdf5(); /* Test detecting HDF5 files correctly */
+ test_file_isaccessible(); /* Test detecting HDF5 files correctly */
test_file_open_dot(); /* Test opening objects with "." for a name */
#ifndef H5_CANNOT_OPEN_TWICE
test_file_open_overlap(); /* Test opening files in an overlapping manner */
@@ -1576,13 +1576,13 @@ test_file_freespace(void)
/****************************************************************
**
-** test_file_ishdf5(): low-level file test routine.
-** This test checks whether the H5Fis_hdf5() routine is working
+** test_file_isaccessible(): low-level file test routine.
+** This test checks whether the H5Fis_accessible() routine is working
** correctly in variuous situations.
**